@@ -1,6 +1,6 @@
 import sys
 
-from je_auto_control.utils.exception.exception_tag import windows_import_error
+from je_auto_control.utils.exception.exception_tags import windows_import_error
 from je_auto_control.utils.exception.exceptions import AutoControlException
 
 if sys.platform not in ["win32", "cygwin", "msys"]:
@@ -10,8 +10,8 @@ import ctypes
 
 
 def check_key_is_press(keycode: [int, str]) -> bool:
-    if type(keycode) is int:
-        temp = ctypes.windll.user32.GetKeyState(keycode)
+    if isinstance(keycode, int):
+        temp: int = ctypes.windll.user32.GetKeyState(keycode)
     else:
         temp = ctypes.windll.user32.GetKeyState(ord(keycode))
     if temp > 1:
